==> open-xchange-guard-ui_2.10.1.orig.tar.bz2: open-xchange-guard-ui-2.10.1/oxguard-ui/apps/oxguard/mail/oxguard_mail_compose_core.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016-2020 OX Software GmbH
 */
define('oxguard/mail/oxguard_mail_compose_core', [
    'io.ox/core/extensions',
    'oxguard/core/og_http',
    'io.ox/core/notifications',
    'oxguard/util',
    'settings!oxguard',
    'io.ox/core/tk/dialogs',
    'gettext!oxguard',
    'less!oxguard/mail/style'
], function (ext, og_http, notify, util, settings, dialogs, gt) {
    'use strict';

    //#. %s product name
    var guesticon = '<i id="newguest" class="fa fa-male oxguard_token key_tooltip" style="color:#5DCD55;" data-toggle="tooltip"/>';
    //#. Have encryption key - Shown on icon hover when a key symbol is displayed for recipient.  We/Guard have an encryption key for the recipient.
    var keyicon = '<i class="fa fa-key oxguard_token key_tooltip" aria-hidden="true" data-toggle="tooltip"></i>';
    //#. %s product name
    var failicon = '<i id="newguest" class="fa fa-ban oxguard_token" style="color:red;"/>';
    var prompting = false;

    // 7.8 compose code

    function drawKeyIcons(info, location) {
        var input = $(location).parent().find('.token-input');
        var inputwidth = input.width() - 30;
        var key = $(keyicon);
        if (info && info.result) {
            switch (info.result) {
            case 'pgp' :
                if (info.key.keySource && info.key.keySource.trusted) {
                    key.addClass('trusted_key');
                } else {
                    key.addClass('untrusted_key');
                }
                createTooltip (info.key, key);
                $(location).find('.close').before(key);
                break;
            case 'new' :
                key.addClass('trusted_key');
                $(location).find('.close').before(key);
                createTooltip ('new', key);
                break;
            case 'guest' :
                var gKey = $(guesticon);
                $(location).find('.close').before(gKey);
                createTooltip ('guest', gKey);
                break;
            case 'fail' :
                $(location).find('.close').before(failicon);

                break;
            }
        }
        input.width(inputwidth);
    }

    function createTooltip (data, loc) {
        require(['oxguard/pgp/keyDetails'], function (pubKeys) {
            var div = $('<div>');
            if (data === 'new') {  // New recipient
                div.append(gt('Key will be created upon sending.'));
            } else if (data === 'guest') {
                div.append(gt('Will create new guest account for %s', window.oxguarddata.productName));
            } else {
                var detail = pubKeys.keyDetail ([data], true);
                div = $(detail.div).find('#keyDetail');
                div.append(gt('Source: ') + getSourceTranslation(data.keySource.name) + '<br/>');
                div.append(data.keySource.trusted ? gt('Trusted') : gt('Untrusted Source'));
                div.addClass(data.keySource.trusted ? 'trusted_key' : 'untrusted_key');
            }
            $(loc).tooltip({
                title: div,
                trigger: 'hover',
                placement: 'bottom',
                html: true,
                delay: 200,
                animation: true,
                viewport: { selector: '.io-ox-mail-compose', padding: 10 }
            });
        });
    }

    function getSourceTranslation (source) {
        switch (source) {
        case 'HKP_PUBLIC_SERVER':
            return gt('Public server');
        case 'HKP_SRV_DNSSEC_SERVER':
            return gt('Secure DNS referred');
        case 'HKP_TRUSTED_SERVER':
            return gt('Trusted server');
        case 'HKP_SRV_SERVER':
            return gt('DNS referred');
        case 'HKP_CACHE':
            return gt('DNS referred');
        case 'GUARD_KEY_PAIR':
            return gt('System key');
        case 'GUARD_USER_UPLOADED':
            return gt('Uploaded key');
        case 'GUARD_USER_SHARED':
            return gt('Shared key');
        default:
            return source;
        }
    }

    // Return a has of string
    function hash(str) {
        var hashed = 0;
        if (str.length === 0) return hashed;
        for (var i = 0; i < str.length; i++) {
            hashed = (31 * hashed + str.charCodeAt(i)) << 0;
        }
        return hashed;
    }

    function checkrecipient(baton) {
        if (!util.isGuardConfigured()) {
            if (!prompting) {
                prompting = true;
                require(['oxguard/oxguard_core', 'oxguard/core/createKeys'], function (core, keys) {
                    core.metrics('mail', 'create-keys-from-compose');
                    keys.createKeysWizard()
                    .done(function () {
                        checkrecipient(baton);
                    })
                    .fail(function () {
                        unlock(baton);
                    })
                    .always(function () {
                        prompting = false;
                    });
                });
            }
            return;// Do not check recipients until the master key is created (in case mailing to self)
        }
        require(['oxguard/mail/keymanager'], function (keyman) {
            keyman.checkAll(baton);
        });
    }

    function unlock(baton) {
        if (_.device('smartphone')) {
            $('.btn-primary:visible').html(gt('Send'));
        } else {
            if (baton.view.app.get('window')) {
                var headerview = baton.view.app.get('window').nodes.header;
                var footerview = baton.view.app.get('window').nodes.footer;
                headerview.find('.btn-primary:visible').html(gt('Send'));
                if (footerview) {
                    footerview.find('.btn-primary:visible').html(gt('Send'));
                }
            }
        }
        baton.view.$el.find('.oxguard_key').hide();
        baton.view.$el.find('.oxguard_token').hide();
        baton.view.model.set('encrypt', false);
        var security = baton.view.model.get('security');
        security.encrypt = false;
        baton.view.model.set('security', security);
        var format = baton.view.model.get('PGPFormat');
        if (format === 'inline' || format === 'i') {  // Deactivate the Format types if not encrypted
            baton.view.model.set('PGPFormat', 'i');
        } else {
            baton.view.model.set('PGPFormat', 'm');
        }
    }

    function lock(baton) {

        var security = baton.view.model.get('security');
        security.encrypt = true;
        baton.view.model.set('security', security);
        if (_.device('smartphone')) {
            $('.btn-primary:visible').html((settings.get('advanced') ? gt ('Send Encrypted') : gt('Send Secure')));
        } else {
            var headerview = baton.view.app.get('window').nodes.header;
            var footerview = baton.view.app.get('window').nodes.footer;
            headerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt ('Send Encrypted') : gt('Send Secure')));
            if (footerview) {
                footerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt ('Send Encrypted') : gt('Send Secure')));
            }
        }
        checkrecipient(baton);
        baton.view.$el.find('.oxguard_key').show();
        baton.view.$el.find('.oxguard_token').show();
        baton.view.model.set('encrypt', true);
        var format = baton.view.model.get('PGPFormat');
        if (format === 'i') {  // Activate the Format types if encrypted
            baton.view.model.set('PGPFormat', 'inline');
        } else {
            if (format === 'm') baton.view.model.set('PGPFormat', 'mime');
        }
    }

    return {
        lock: lock,
        hash: hash,
        unlock: unlock,
        drawKeyIcons: drawKeyIcons
    };
});

==> open-xchange-guard-ui_2.10.3.orig.tar.bz2: open-xchange-guard-ui-2.10.3/oxguard-ui/apps/oxguard/mail/oxguard_mail_compose_core.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016-2020 OX Software GmbH
 */
define('oxguard/mail/oxguard_mail_compose_core', [
    'io.ox/core/extensions',
    'oxguard/core/og_http',
    'io.ox/core/notifications',
    'oxguard/util',
    'settings!oxguard',
    'io.ox/core/tk/dialogs',
    'gettext!oxguard',
    'less!oxguard/mail/style'
], function (ext, og_http, notify, util, settings, dialogs, gt) {
    'use strict';

    //#. %s product name
    var guesticon = '<i id="newguest" class="fa fa-male oxguard_token key_tooltip" style="color:#5DCD55;" data-toggle="tooltip"/>';
    //#. Have encryption key - Shown on icon hover when a key symbol is displayed for recipient.  We/Guard have an encryption key for the recipient.
    var keyicon = '<i class="fa fa-key oxguard_token key_tooltip" aria-hidden="true" data-toggle="tooltip"></i>';
    //#. %s product name
    var failicon = '<i id="newguest" class="fa fa-ban oxguard_token" style="color:red;"/>';
    var prompting = false;

    // 7.8 compose code

    function drawKeyIcons(info, location) {
        var input = $(location).parent().find('.token-input');
        var inputwidth = input.width() - 30;
        var key = $(keyicon);
        if (info && info.result) {
            switch (info.result) {
                case 'pgp' :
                    if (info.key.keySource && info.key.keySource.trusted) {
                        key.addClass('trusted_key');
                    } else {
                        key.addClass('untrusted_key');
                    }
                    createTooltip(info.key, key);
                    $(location).find('.close').before(key);
                    break;
                case 'new' :
                    key.addClass('trusted_key');
                    $(location).find('.close').before(key);
                    createTooltip('new', key);
                    break;
                case 'guest' :
                    var gKey = $(guesticon);
                    $(location).find('.close').before(gKey);
                    createTooltip('guest', gKey);
                    break;
                case 'fail' :
                    $(location).find('.close').before(failicon);

                    break;
                default:
                    console.error('Unkown key type ' + info.result);
            }
        }
        input.width(inputwidth);
    }

    function createTooltip(data, loc) {
        require(['oxguard/pgp/keyDetails'], function (pubKeys) {
            var div = $('<div>');
            if (data === 'new') {  // New recipient
                div.append(gt('Key will be created upon sending.'));
            } else if (data === 'guest') {
                div.append(gt('Will create new guest account for %s', window.oxguarddata.productName));
            } else {
                var detail = pubKeys.keyDetail([data], true);
                div = $(detail.div).find('#keyDetail');
                div.append(gt('Source: ') + getSourceTranslation(data.keySource.name) + '<br/>');
                div.append(data.keySource.trusted ? gt('Trusted') : gt('Untrusted Source'));
                div.addClass(data.keySource.trusted ? 'trusted_key' : 'untrusted_key');
            }
            $(loc).tooltip({
                title: div.html(),
                trigger: 'hover',
                placement: 'bottom',
                html: true,
                delay: 200,
                animation: true,
                viewport: { selector: '.io-ox-mail-compose', padding: 10 }
            });
        });
    }

    function getSourceTranslation(source) {
        switch (source) {
            case 'HKP_PUBLIC_SERVER':
                return gt('Public server');
            case 'HKP_SRV_DNSSEC_SERVER':
                return gt('Secure DNS referred');
            case 'HKP_TRUSTED_SERVER':
                return gt('Trusted server');
            case 'HKP_SRV_SERVER':
                return gt('DNS referred');
            case 'HKP_CACHE':
                return gt('DNS referred');
            case 'GUARD_KEY_PAIR':
                return gt('System key');
            case 'GUARD_USER_UPLOADED':
                return gt('Uploaded key');
            case 'GUARD_USER_SHARED':
                return gt('Shared key');
            case 'WKS_SERVER':
                return gt('WebKey Directory Service');
            case 'WKS_SRV_DNSSEC_SERVER':
                return gt('WebKey DNSEC Service');
            case 'AUTOCRYPT_KEY':
                return gt('Autocrypt Keys');
            case 'AUTOCRYPT_KEY_USER_VERIFIED':
                return gt('Autocrypt Keys');
            default:
                return source;
        }
    }

    // Return a has of string
    function hash(str) {
        var hashed = 0;
        if (str.length === 0) return hashed;
        for (var i = 0; i < str.length; i++) {
            hashed = (31 * hashed + str.charCodeAt(i)) << 0;
        }
        return hashed;
    }

    function checkrecipient(baton) {
        if (!util.isGuardConfigured()) {
            if (!prompting) {
                prompting = true;
                require(['oxguard/oxguard_core', 'oxguard/core/createKeys'], function (core, keys) {
                    core.metrics('mail', 'create-keys-from-compose');
                    keys.createKeysWizard()
                    .done(function () {
                        checkrecipient(baton);
                    })
                    .fail(function () {
                        unlock(baton);
                    })
                    .always(function () {
                        prompting = false;
                    });
                });
            }
            return;// Do not check recipients until the master key is created (in case mailing to self)
        }
        require(['oxguard/mail/keymanager'], function (keyman) {
            keyman.checkAll(baton);
        });
    }

    function unlock(baton) {
        if (_.device('smartphone')) {
            $('.btn-primary:visible').html(gt('Send'));
        } else if (baton.view.app.get('window')) {
            var headerview = baton.view.app.get('window').nodes.header;
            var footerview = baton.view.app.get('window').nodes.footer;
            headerview.find('.btn-primary:visible').html(gt('Send'));
            if (footerview) {
                footerview.find('.btn-primary:visible').html(gt('Send'));
            }
        }
        baton.view.$el.find('.oxguard_key').hide();
        baton.view.$el.find('.oxguard_token').hide();
    }

    function lock(baton) {
        if (_.device('smartphone')) {
            $('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
        } else {
            var headerview = baton.view.app.get('window').nodes.header;
            var footerview = baton.view.app.get('window').nodes.footer;
            headerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
            if (footerview) {
                footerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt('Send Encrypted') : gt('Send Secure')));
            }
        }
        checkrecipient(baton);
        baton.view.$el.find('.oxguard_key').show();
        baton.view.$el.find('.oxguard_token').show();
    }

    return {
        lock: lock,
        hash: hash,
        unlock: unlock,
        drawKeyIcons: drawKeyIcons
    };
});
